@@ -3,9 +3,9 @@
 from urllib.parse import urljoin
 
 __name__ = "xarg-python"
-__version__ = "1.3"
+__version__ = "1.3.1"
 __description__ = "Simple command-line tool based on argparse."
-__url_home__ = "https://github.com/bondbox/xarg-python"
+__url_home__ = "https://github.com/bondbox/xarg-python/"
 __url_code__ = __url_home__
 __url_docs__ = __url_home__
 __url_bugs__ = urljoin(__url_home__, "issues")
