@@ -2,6 +2,7 @@
 
 
 import os
+import shutil
 from typing import List
 
 from .attribute import __author__
@@ -30,16 +31,14 @@ def singleton(cls):
 
 @singleton
 class chdir:
-    '''
-    Change directory
+    '''Change directory
     '''
 
     def __init__(self):
         self.__stack: List[str] = []
 
     def pushd(self, path: str):
-        '''
-        Add directory to stack.
+        '''Add directory to stack.
         '''
         assert isinstance(path, str), f"type '{type(path)}' is not str"
         assert os.path.isdir(path), f"path '{path}' is not directory"
@@ -47,8 +46,32 @@ class chdir:
         os.chdir(path)
 
     def popd(self):
-        '''
-        Remove directory from stack.
+        '''Remove directory from stack.
         '''
         assert len(self.__stack) > 0
         os.chdir(self.__stack.pop())
+
+
+class safile:
+    '''Secure read and write files
+    '''
+
+    @classmethod
+    def backup(cls, path: str) -> bool:
+        pbak: str = f"{path}.bak"
+        assert not os.path.exists(pbak), f"backup '{pbak}' already exists"
+        if not os.path.exists(path):
+            return True
+        assert os.path.isfile(path), f"'{path}' is not a regular file"
+        assert shutil.move(src=path, dst=pbak) == pbak
+        return os.path.exists(pbak)
+
+    @classmethod
+    def restore(cls, path: str) -> bool:
+        pbak: str = f"{path}.bak"
+        if os.path.isfile(pbak):
+            if os.path.isfile(path):
+                os.remove(path)
+            assert not os.path.exists(path), f"restore {path} still exists"
+            assert shutil.move(src=pbak, dst=path) == path
+        return not os.path.exists(pbak)
